nj.tree: Draw ggtree based phylogenetic tree using DNA or protein...

Description Usage Arguments Value Author(s) Examples

View source: R/nj.tree.R

Description

Draw ggtree based phylogenetic tree using DNA or protein sequences

Usage

1
nj.tree(file, align.method = "muscle", html = TRUE, plot = TRUE)

Arguments

file

a file path. The file containg the sequences in fasta format.

align.method

method for multiple sequences alignment, one of "muscle" and "DECIPHER"

html

a boolean value to indicate if to show the alignment result in the explore

plot

a boolean value if draw the tree using ggtree package

Value

a ggtree plot

Author(s)

Zhonghui Gai

Examples

1
nj.tree("prob.16S.fa")

ZhonghuiGai/ggtreeEx documentation built on Dec. 18, 2021, 9:20 p.m.