Description Usage Arguments Value Author(s) Examples
Draw ggtree based phylogenetic tree using DNA or protein sequences
1 |
file |
a file path. The file containg the sequences in fasta format. |
align.method |
method for multiple sequences alignment, one of "muscle" and "DECIPHER" |
html |
a boolean value to indicate if to show the alignment result in the explore |
plot |
a boolean value if draw the tree using ggtree package |
a ggtree plot
Zhonghui Gai
1 | nj.tree("prob.16S.fa")
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.